summaryrefslogtreecommitdiffstats
path: root/kimagemapeditor/qextfileinfo.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:39:24 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:39:24 -0600
commitf9ced3b3f13f3136ef63c33ef163042010d6e80b (patch)
tree293ce93dfb0dcfd79f83674116d7b3bc56f29af2 /kimagemapeditor/qextfileinfo.cpp
parent29df04c24350cc76a41e2410d1c92445f9338b98 (diff)
downloadtdewebdev-f9ced3b3f13f3136ef63c33ef163042010d6e80b.tar.gz
tdewebdev-f9ced3b3f13f3136ef63c33ef163042010d6e80b.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kimagemapeditor/qextfileinfo.cpp')
-rw-r--r--kimagemapeditor/qextfileinfo.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kimagemapeditor/qextfileinfo.cpp b/kimagemapeditor/qextfileinfo.cpp
index 5ef6d8d0..440e9c78 100644
--- a/kimagemapeditor/qextfileinfo.cpp
+++ b/kimagemapeditor/qextfileinfo.cpp
@@ -143,7 +143,7 @@ bool QExtFileInfo::createDir( const KURL& path )
// debug(d1);
}
// dir2.setPath(dir2.path(-1));
- result = KIO::NetAccess::mkdir(dir2, 0L, -1);
+ result = TDEIO::NetAccess::mkdir(dir2, 0L, -1);
i++;
}
result = exists(path);
@@ -184,7 +184,7 @@ bool QExtFileInfo::exists(const KURL& a_url)
{
// Andras: Don't use it now, as it brings up an extra dialog and need manual
// intervention when usign fish
-// return KIO::NetAccess::exists(a_url, false);
+// return TDEIO::NetAccess::exists(a_url, false);
// No dialog when stating.
if ( a_url.isLocalFile() )
@@ -219,11 +219,11 @@ KURL::List QExtFileInfo::allFilesInternal(const KURL& startURL, const TQString&
lstFilters.append( new TQRegExp(*it, false, true ) );
bJobOK = true;
- KIO::ListJob *job = KIO::listRecursive(startURL, false, true);
- connect(job, TQT_SIGNAL(entries(KIO::Job *, const KIO::UDSEntryList&)),
- this, TQT_SLOT(slotNewEntries(KIO::Job *, const KIO::UDSEntryList&)));
- connect( job, TQT_SIGNAL( result (KIO::Job *) ),
- this, TQT_SLOT( slotResult (KIO::Job *) ) );
+ TDEIO::ListJob *job = TDEIO::listRecursive(startURL, false, true);
+ connect(job, TQT_SIGNAL(entries(TDEIO::Job *, const TDEIO::UDSEntryList&)),
+ this, TQT_SLOT(slotNewEntries(TDEIO::Job *, const TDEIO::UDSEntryList&)));
+ connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
+ this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
// kdDebug(24000) << "Now listing: " << startURL.url() << endl;
enter_loop();
@@ -238,17 +238,17 @@ KURL::List QExtFileInfo::allFilesInternal(const KURL& startURL, const TQString&
}
//Some hackery from KIO::NetAccess as they do not do exactly what we want
/* return true if the url exists*/
bool QExtFileInfo::internalExists(const KURL& url)
{
bJobOK = true;
// kdDebug(24000)<<"QExtFileInfo::internalExists"<<endl;
- KIO::StatJob * job = KIO::stat( url, false);
+ TDEIO::StatJob * job = TDEIO::stat( url, false);
job->setDetails(0);
job->setSide(false); //check the url for writing
- connect( job, TQT_SIGNAL( result (KIO::Job *) ),
- this, TQT_SLOT( slotResult (KIO::Job *) ) );
+ connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
+ this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
//To avoid lock-ups, start a timer.
TQTimer::singleShot(10*1000, this,TQT_SLOT(slotTimeout()));
@@ -263,11 +263,11 @@ bool QExtFileInfo::internalCopy(const KURL& src, const KURL& target, int permiss
{
bJobOK = true; // success unless further error occurs
- KIO::Scheduler::checkSlaveOnHold(true);
- KIO::Job * job = KIO::file_copy( src, target, permissions, overwrite, resume );
+ TDEIO::Scheduler::checkSlaveOnHold(true);
+ TDEIO::Job * job = TDEIO::file_copy( src, target, permissions, overwrite, resume );
job->setWindow (window);
- connect( job, TQT_SIGNAL( result (KIO::Job *) ),
- this, TQT_SLOT( slotResult (KIO::Job *) ) );
+ connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
+ this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
enter_loop();
return bJobOK;
@@ -288,7 +288,7 @@ void QExtFileInfo::enter_loop()
tqt_leave_modal(&dummy);
}
-void QExtFileInfo::slotResult( KIO::Job * job )
+void QExtFileInfo::slotResult( TDEIO::Job * job )
{
bJobOK = !job->error();
if ( !bJobOK )
@@ -296,30 +296,30 @@ void QExtFileInfo::slotResult( KIO::Job * job )
if ( !lastErrorMsg )
lastErrorMsg = job->errorString();
}
- if ( job->isA("KIO::StatJob") )
- m_entry = static_cast<KIO::StatJob *>(job)->statResult();
+ if ( job->isA("TDEIO::StatJob") )
+ m_entry = static_cast<TDEIO::StatJob *>(job)->statResult();
tqApp->exit_loop();
}
-void QExtFileInfo::slotNewEntries(KIO::Job *job, const KIO::UDSEntryList& udsList)
+void QExtFileInfo::slotNewEntries(TDEIO::Job *job, const TDEIO::UDSEntryList& udsList)
{
- KURL url = static_cast<KIO::ListJob *>(job)->url();
+ KURL url = static_cast<TDEIO::ListJob *>(job)->url();
url.adjustPath(-1);
// avoid creating these TQStrings again and again
static const TQString& dot = TDEGlobal::staticQString(".");
static const TQString& dotdot = TDEGlobal::staticQString("..");
- KIO::UDSEntryListConstIterator it = udsList.begin();
- KIO::UDSEntryListConstIterator end = udsList.end();
+ TDEIO::UDSEntryListConstIterator it = udsList.begin();
+ TDEIO::UDSEntryListConstIterator end = udsList.end();
KURL itemURL;
for ( ; it != end; ++it )
{
TQString name;
// find out about the name
- KIO::UDSEntry::ConstIterator entit = (*it).begin();
+ TDEIO::UDSEntry::ConstIterator entit = (*it).begin();
for( ; entit != (*it).end(); ++entit )
- if ( (*entit).m_uds == KIO::UDS_NAME )
+ if ( (*entit).m_uds == TDEIO::UDS_NAME )
{
name = (*entit).m_str;
break;
@@ -238,17 +238,17 @@ KURL::List QExtFileInfo::allFilesInternal(const KURL& startURL, const TQString&
}
-//Some hackery from KIO::NetAccess as they do not do exactly what we want
+//Some hackery from TDEIO::NetAccess as they do not do exactly what we want
/* return true if the url exists*/
bool QExtFileInfo::internalExists(const KURL& url)